/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.fortunecookies.app.mainplugin;

import org.gvsig.andami.messages.NotificationManager;
import org.gvsig.andami.plugins.Extension;
import org.gvsig.fortunecookies.FortuneCookieLocator;
import org.gvsig.fortunecookies.FortuneCookieManager;
import org.gvsig.fortunecookies.FortuneCookieService;
import org.gvsig.fortunecookies.swing.FortuneCookieSwingLocator;
import org.gvsig.fortunecookies.swing.FortuneCookieSwingManager;
import org.gvsig.fortunecookies.swing.JFortuneCookieServicePanel;
import org.gvsig.tools.dynobject.DynObject;
import org.gvsig.tools.service.ServiceException;
import org.gvsig.tools.swing.api.windowmanager.WindowManager;

/**
 * Andami extension to show fortune cookies in the application.
 * 
 * @author gvSIG Team
 * @version $Id$
 */
public class FortuneCookieExtension extends Extension {

	private FortuneCookieManager manager;
	private FortuneCookieSwingManager swingManager;

	public void initialize() {
		// Do nothing
	}

	@Override
	public void postInitialize() {
		super.postInitialize();
		manager = FortuneCookieLocator.getManager();
		// Asignamos el locator e iniciamos la instancia
		swingManager = FortuneCookieSwingLocator.getSwingManager();
	}

	public void execute(String actionCommand) {
		showFortuneCookie(manager);
	}

	public void showFortuneCookie(FortuneCookieManager manager) {
		try {
			DynObject parameters = manager
					.createServiceParameters("FortuneCookie.providers.web");
			FortuneCookieService service = (FortuneCookieService) manager
					.getService(parameters);
			JFortuneCookieServicePanel panel = swingManager
					.createFortuneCookie(service);
			swingManager.getWindowManager().showWindow(panel, "Fortune Cookie",
					WindowManager.MODE.DIALOG);

		} catch (ServiceException e) {
			NotificationManager.addError(e);
		}
	}

	public boolean isEnabled() {
		return true;
	}

	public boolean isVisible() {
		return true;
	}

}
