/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.fortunecookies;

import org.gvsig.tools.dynobject.DynObject;
import org.gvsig.tools.junit.AbstractLibraryAutoInitTestCase;

/**
 * API compatibility tests for {@link FortuneCookieService} implementations.
 * 
 * @author gvSIG Team
 * @version $Id$
 */
public abstract class FortuneCookieServiceTest extends
    AbstractLibraryAutoInitTestCase {

    protected FortuneCookieManager manager;

    @Override
    protected void doSetUp() throws Exception {
        manager = FortuneCookieLocator.getManager();
    }

    /**
     * Returns an instance of the {@link FortuneCookieService}.
     * 
     * @return a {@link FortuneCookieService} instance
     * @throws Exception
     *             if there is any error creating the instance
     */
    protected FortuneCookieService createService() throws Exception {
        DynObject parameters =
            manager
                .createServiceParameters(FortuneCookieManagerTest.TEST_PROVIDER_NAME);
        return (FortuneCookieService) manager.getService(parameters);
    }

    /**
     * Test for the {@link FortuneCookieService#getMessage()} method.
     * 
     * @throws Exception
     *             if there is any error in the tests
     */
    public void testFortuneCookieServiceMessage() throws Exception {
        FortuneCookieService cookie = createService();

        String message = null;
        message = cookie.getMessage();

        assertNotNull(message);
        assertTrue(message.length() > 0);
    }

    /**
     * Test for the {@link FortuneCookieService#getDate()} method.
     * 
     * @throws Exception
     *             if there is any error in the tests
     */
    public void testFortuneCookieServiceDate() throws Exception {
        FortuneCookieService cookie = createService();
        cookie.getMessage();
        assertNotNull(cookie.getDate());
    }

    /**
     * Test for the {@link FortuneCookieService#getManager()} method.
     * 
     * @throws Exception
     *             if there is any error in the tests
     */
    public void testFortuneCookieServiceManager() throws Exception {
        FortuneCookieService cookie = createService();
        assertEquals(manager, cookie.getManager());
    }
}
