/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.fortunecookies.main;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JToolBar;
import javax.swing.WindowConstants;

import org.gvsig.fortunecookies.FortuneCookieLocator;
import org.gvsig.fortunecookies.FortuneCookieManager;
import org.gvsig.fortunecookies.FortuneCookieService;
import org.gvsig.fortunecookies.swing.FortuneCookieSwingLocator;
import org.gvsig.fortunecookies.swing.FortuneCookieSwingManager;
import org.gvsig.fortunecookies.swing.JFortuneCookieServicePanel;
import org.gvsig.tools.dynobject.DynObject;
import org.gvsig.tools.library.impl.DefaultLibrariesInitializer;
import org.gvsig.tools.service.ServiceException;
import org.gvsig.tools.swing.api.windowmanager.WindowManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Main executable class for testing the fortune cookies library.
 * 
 * @author gvSIG Team
 * @version $Id$
 */
public class Main {

	private static final Logger LOG = LoggerFactory.getLogger(Main.class);

	private FortuneCookieManager manager;
	private FortuneCookieSwingManager swingManager;

	public static void main(String args[]) {
		new DefaultLibrariesInitializer().fullInitialize();
		Main main = new Main();
		main.show();
	}

	@SuppressWarnings("serial")
	public void show() {
		manager = FortuneCookieLocator.getManager();
		swingManager = FortuneCookieSwingLocator.getSwingManager();

		Action showCookie = new AbstractAction("Get a fortune cookie") {

			public void actionPerformed(ActionEvent e) {
				showFortuneCookie(manager);
			}
		};

		Action exit = new AbstractAction("Exit") {

			public void actionPerformed(ActionEvent e) {
				System.exit(0);
			}
		};

		JFrame frame = new JFrame("Fortune Cookie example app");
		frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);

		// Create the menu bar.
		JMenuBar menuBar = new JMenuBar();

		// Build the menu.
		JMenu menuFile = new JMenu("File");
		menuFile.add(new JMenuItem(showCookie));
		menuFile.add(new JMenuItem(exit));

		menuBar.add(menuFile);

		JToolBar toolBar = new JToolBar();
		toolBar.add(new JButton(showCookie));
		toolBar.add(new JButton(exit));

		frame.setPreferredSize(new Dimension(200, 100));
		frame.setJMenuBar(menuBar);
		frame.add(toolBar, BorderLayout.PAGE_START);

		// Display the window.
		frame.pack();
		frame.setVisible(true);
	}

	public void showFortuneCookie(FortuneCookieManager manager) {
		try {
			DynObject parameters = manager
					.createServiceParameters("FortuneCookie.providers.file");
			FortuneCookieService service = (FortuneCookieService) manager
					.getService(parameters);
			JFortuneCookieServicePanel panel = swingManager
					.createFortuneCookie(service);
			swingManager.getWindowManager().showWindow(panel, "Fortune Cookie",
					WindowManager.MODE.WINDOW);
		} catch (ServiceException e) {
			LOG.error("Error showing a fortune cookie", e);
		}
	}

}
