/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.fortunecookies.prov.fileprovider;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Random;

import org.gvsig.fortunecookies.FortuneCookieMessageException;
import org.gvsig.fortunecookies.lib.spi.FortuneCookieProvider;
import org.gvsig.tools.service.spi.AbstractProvider;
import org.gvsig.tools.service.spi.ProviderServices;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * FortuneCookie provider which gets fortune cookies from a file.
 * 
 * @author gvSIG Team
 * @version $Id$
 */
public class FortuneCookieFileProvider extends AbstractProvider implements
    FortuneCookieProvider {

    private static final Logger LOG =
        LoggerFactory.getLogger(FortuneCookieFileProvider.class);

    private final File file;

    /**
     * Constructor.
     * 
     * @param providerServices
     *            the services for the provider
     * @param file
     *            to get the fortune cookies from
     */
    public FortuneCookieFileProvider(ProviderServices providerServices,
        File file) {
        super(providerServices);
        this.file = file;
    }

    public String getMessage() throws FortuneCookieMessageException {
        LOG.debug("Getting the fortune cookie message from the file: {}",
            this.file);

        StringBuffer messageText;
        String messageFragment;

        List<String> messages = null;

        try {
            messages = new ArrayList<String>();
            FileReader fileReader = new FileReader(this.file);
            BufferedReader bfReader = new BufferedReader(fileReader);
            messageFragment = bfReader.readLine();
            while (messageFragment != null) {
                messageText = new StringBuffer();
                while (messageFragment != null && messageFragment.length() > 0
                    && messageFragment.charAt(0) != '\n') {
                    messageText.append('\n').append(messageFragment);
                    messageFragment = bfReader.readLine();
                }
                messages.add(messageText.toString());
                messageFragment = bfReader.readLine();
            }
            bfReader.close();
            fileReader.close();

        } catch (IOException e) {
            throw new FortuneCookieMessageException(e);
        }
        Random rand = new Random();
        int index = rand.nextInt(messages.size());

        return messages.get(index);
    }

}
