/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.fortunecookies.prov.fileprovider;

import java.io.File;
import java.net.URL;

import org.gvsig.fortunecookies.lib.spi.FortuneCookieProvider;
import org.gvsig.tools.ToolsLocator;
import org.gvsig.tools.dataTypes.DataTypes;
import org.gvsig.tools.dynobject.DynClass;
import org.gvsig.tools.dynobject.DynObject;
import org.gvsig.tools.service.ServiceException;
import org.gvsig.tools.service.spi.Provider;
import org.gvsig.tools.service.spi.ProviderFactory;
import org.gvsig.tools.service.spi.ProviderServices;

/**
 * Factory of file {@link FortuneCookieProvider} objects.
 * 
 * @author gvSIG Team
 * @version $Id$
 */
public class FortuneCookieFileProviderFactory implements ProviderFactory {

	private static final String PROVIDER_NAME = "FortuneCookie.providers.file";
	private static final String PROVIDER_DESCRIPTION = "Provider to load fortune cookies from a web site";

	private static final String PARAMETER_FILE = "File";

	private DynClass parametersDefinition;

	public Provider create(DynObject parameters, ProviderServices services)
			throws ServiceException {
		return new FortuneCookieFileProvider(services, (File) parameters
				.getDynValue(PARAMETER_FILE));
	}

	public DynObject createParameters() {
		return ToolsLocator.getDynObjectManager().createDynObject(
				parametersDefinition);
	}

	public String getName() {
		return PROVIDER_NAME;
	}

	public void initialize() {
		URL url = getClass().getResource("messages.txt");

		parametersDefinition = ToolsLocator.getDynObjectManager()
				.createDynClass(PROVIDER_NAME, PROVIDER_DESCRIPTION);
		parametersDefinition.addDynField(PARAMETER_FILE)
				.setType(DataTypes.FILE).setMandatory(true).setDefaultDynValue(
						new File(url.getFile()));
	}

}
