/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.fortunecookies.prov.webprovider;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.regex.Pattern;

import org.gvsig.fortunecookies.FortuneCookieMessageException;
import org.gvsig.fortunecookies.lib.spi.FortuneCookieProvider;
import org.gvsig.tools.service.spi.AbstractProvider;
import org.gvsig.tools.service.spi.ProviderServices;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * FortuneCookie provider which gets fortune cookies from a URL.
 * 
 * @author gvSIG Team
 * @version $Id$
 */
public class FortuneCookieWebProvider extends AbstractProvider implements
    FortuneCookieProvider {

    private static final Logger LOG =
        LoggerFactory.getLogger(FortuneCookieWebProvider.class);

    private final String url;

    /**
     * Constructor.
     * 
     * @param providerServices
     *            the services for the provider
     * @param url
     *            to get the fortune cookies from
     */
    public FortuneCookieWebProvider(ProviderServices providerServices,
        String url) {
        super(providerServices);
        this.url = url;
    }

    public String getMessage() throws FortuneCookieMessageException {
        LOG.debug("Getting the fortune cookie message from the url: {}",
            this.url);

        try {
            URL url = new URL(this.url);
            StringBuffer message = new StringBuffer();
            BufferedReader in =
                new BufferedReader(new InputStreamReader(url.openStream()));
            String str;
            // Create a pattern to match breaks
            Pattern p = Pattern.compile("\\<[^\\>]+\\>");

            StringBuffer data = null;

            if (LOG.isDebugEnabled()) {
                data = new StringBuffer();
            }

            while ((str = in.readLine()) != null) {
                if (LOG.isDebugEnabled()) {
                    data.append(str).append('\n');
                }
                message.append(p.matcher(str).replaceAll("\n"));
            }
            in.close();

            LOG.debug("Fortune cookie message response:\n{}", data);

            return message.toString();
        } catch (IOException e) {
            throw new FortuneCookieMessageException(e);
        }
    }

    @Override
    public String toString() {
        return "Web provider, url = ".concat(url);
    }
}
