/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.fortunecookies.swing;

import org.gvsig.fortunecookies.FortuneCookieManager;
import org.gvsig.fortunecookies.FortuneCookieService;
import org.gvsig.tools.swing.api.windowmanager.WindowManager;

/**
 * This class is responsible of the management of the library's swing user
 * interface. It is the swing library's main entry point, and provides all the
 * services to manage library swing components.
 * 
 * @see JFortuneCookieServicePanel
 * @author gvSIG team
 * @version $Id$
 */
public interface FortuneCookieSwingManager {

    /**
     * Returns the panel associated to a {@link FortuneCookieService}.
     * 
     * @param cookie
     *            {@link FortuneCookieService} contained on the panel
     * @return a {@link JFortuneCookieServicePanel} with the panel of the
     *         {@link FortuneCookieService}
     * @see JFortuneCookieServicePanel
     * @see FortuneCookieService
     */
    public JFortuneCookieServicePanel createFortuneCookie(
        FortuneCookieService cookie);

    /**
     * Returns the {@link FortuneCookieManager}.
     * 
     * @return {@link FortuneCookieManager}
     * @see {@link FortuneCookieManager}
     */
    public FortuneCookieManager getManager();

    /**
     * Returns the translation of a string.
     * 
     * @param key
     *            String to translate
     * @return a String with the translation of the string passed by parameter
     */
    public String getTranslation(String key);

    /**
     * Returns the {@link WindowManager}.
     * 
     * @return {@link WindowManager}
     */
    public WindowManager getWindowManager();
}
