/**
 * gvSIG. Desktop Geographic Information System.
 *
 * Copyright (C) 2007-2012 gvSIG Association.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * For any additional information, do not hesitate to contact us
 * at info AT gvsig.com, or visit our website www.gvsig.com.
 */
package org.gvsig.landregistryviewer.swing.impl;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Iterator;
import java.util.List;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import org.gvsig.landregistryviewer.LandRegistryViewerBlock;
import org.gvsig.landregistryviewer.LandRegistryViewerException;
import org.gvsig.landregistryviewer.LandRegistryViewerProperty;
import org.gvsig.landregistryviewer.swing.JLandRegistryViewerBlockPanel;
import org.gvsig.landregistryviewer.swing.LandRegistryViewerSwingManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DefaultJLandRegistryViewerBlockPanel extends
JLandRegistryViewerBlockPanel {

/**
 * 
 */
private static final long serialVersionUID = 3638250585757641443L;


private static final Logger LOG =
    LoggerFactory.getLogger(DefaultJLandRegistryViewerBlockPanel.class);


private LandRegistryViewerBlock block;
private LandRegistryViewerSwingManager uimanager;

protected JButton accept = null;

public DefaultJLandRegistryViewerBlockPanel(
    DefaultLandRegistryViewerSwingManager uimanager, LandRegistryViewerBlock block) {

    this.block = block;
    this.uimanager = uimanager;

    this.setLayout(new BorderLayout());
    this.setPreferredSize(new Dimension(500, 300));

    JLabel text = new JLabel(getText());

    JScrollPane scrollPane = new JScrollPane(text);
    scrollPane.setPreferredSize(new Dimension(500, 220));

    // TODO: replace with the UsabilitySwingManager.createJButton()
    accept = new JButton(this.uimanager.getTranslation("Accept"));
    
    JPanel optionsPane = new JPanel();
    optionsPane.setLayout(new BoxLayout(optionsPane, BoxLayout.LINE_AXIS));
    optionsPane.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
    optionsPane.add(Box.createHorizontalGlue());

    accept.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent arg0) {
		    setVisible(false);
	    }
    });
    optionsPane.add(accept);
    optionsPane.add(Box.createRigidArea(new Dimension(10, 0)));

    this.add(scrollPane, BorderLayout.CENTER);
    this.add(optionsPane, BorderLayout.SOUTH);
}

public LandRegistryViewerBlock getLandRegistryViewerBlock() {
    return this.block;
}

private String getText() {
    try {
	    List<LandRegistryViewerProperty> properties = this.block.getProperties();

	    StringBuffer buffer = new StringBuffer();
	    buffer.append("<html>\n<body>\n");
	    buffer.append("<p><b>Block</b></p>\n<br>\n");
	    buffer.append("<p>has ");
	    buffer.append(properties.size());
	    buffer.append("properties.</p>\n<br>\n");
	    buffer.append("<ul>\n");

	    Iterator<LandRegistryViewerProperty> it = properties.iterator();
	    while( it.hasNext() ) {
		    LandRegistryViewerProperty property = it.next();
		    buffer.append("<li>Property code ");
		    buffer.append(property.getCode());
		    buffer.append(" of municipality  ");
		    buffer.append(property.getMunicipalityCode());
		    buffer.append(" (");
		    buffer.append(property.getCreationDate());
		    buffer.append(")</li>\n");
	    }
	    buffer.append("</ul>\n");
	    buffer.append("</body>\n</html>\n");
	    return buffer.toString();
	
    } catch (LandRegistryViewerException e) {
	    LOG.error("Can't create description of Block",e);

	    StringBuffer buffer = new StringBuffer();
	    buffer.append("<html>\n<body>\n");
	    buffer.append("<p>Se ha producido un error componiendo la" +
			    "descripcion de la manzana.</p>\n");
	    buffer.append("<pre>\n");
	    buffer.append(e.getMessageStack());
	    buffer.append("\n</pre>\n");
	    buffer.append("</body>\n</html>\n");
	    return buffer.toString();
    }
}
}

